CrimeRawIncidents class

Inheritance

Constructors

CrimeRawIncidents({int? totalIncidents, int? totalPages, List<CrimeRawData>? incidents})
const
CrimeRawIncidents.fromJson(Map<String, dynamic> crimeIncidents)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
incidents List<CrimeRawData>?
List of incidents.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalIncidents int?
Total number of incidents.
finalinherited
totalPages int?
Total number of pages for the request
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited